@@ -2,28 +2,39 @@
 -- Copyright © 2014-2018  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
-
 {-# LANGUAGE OverloadedStrings #-}
 
-module Codec.Encryption.OpenPGP.KeySelection (
-   parseEightOctetKeyId
- , parseFingerprint
-) where
+module Codec.Encryption.OpenPGP.KeySelection
+  ( parseEightOctetKeyId
+  , parseFingerprint
+  ) where
 
 import Codec.Encryption.OpenPGP.Types
 import Control.Applicative (optional)
 import Control.Monad ((<=<))
 import Crypto.Number.Serialize (i2osp)
-import Data.Attoparsec.Text (asciiCI, count, hexadecimal, inClass, parseOnly, Parser, satisfy)
+import Data.Attoparsec.Text
+  ( Parser
+  , asciiCI
+  , count
+  , hexadecimal
+  , inClass
+  , parseOnly
+  , satisfy
+  )
 import qualified Data.ByteString.Lazy as BL
 import Data.Text (Text, toUpper)
 import qualified Data.Text as T
 
 parseEightOctetKeyId :: Text -> Either String EightOctetKeyId
-parseEightOctetKeyId = fmap EightOctetKeyId . (parseOnly hexes <=< parseOnly (hexPrefix *> hexen 16)) . toUpper
+parseEightOctetKeyId =
+  fmap EightOctetKeyId .
+  (parseOnly hexes <=< parseOnly (hexPrefix *> hexen 16)) . toUpper
 
 parseFingerprint :: Text -> Either String TwentyOctetFingerprint
-parseFingerprint = fmap TwentyOctetFingerprint . (parseOnly hexes <=< parseOnly (hexen 40)) . toUpper . T.filter (/=' ')
+parseFingerprint =
+  fmap TwentyOctetFingerprint .
+  (parseOnly hexes <=< parseOnly (hexen 40)) . toUpper . T.filter (/= ' ')
 
 hexPrefix :: Parser (Maybe Text)
 hexPrefix = optional (asciiCI "0x")
