@@ -1,5 +1,5 @@
 -- Signatures.hs: OpenPGP (RFC4880) signature verification
--- Copyright © 2012-2019  Clint Adams
+-- Copyright © 2012-2020  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 module Codec.Encryption.OpenPGP.Signatures
@@ -239,23 +239,38 @@ verifyAgainstKeys ks sig mt payload = do
   let results =
         map
           (\pkp ->
-             verify'
-               sig
+             verifyAgainstKey'
                pkp
-               (hashalgo sig)
-               (BL.toStrict (finalPayload sig payload)))
+               sig
+               mt
+               payload)
           allrelevantpkps
   case rights results of
     [] -> Left (concatMap (++ "/") (lefts results))
     [r] -> do
       _ <- isSignatureExpired sig mt
-      return (Verification r ((_signaturePayload . fromPkt) sig)) -- FIXME: this should also check expiration time and flags of the signing key
+      return r
     _ -> Left "multiple successes; unexpected condition"
   where
     subPKP (pack, _) = subPKP' pack
     subPKP' (PublicSubkeyPkt p) = p
     subPKP' (SecretSubkeyPkt p _) = p
     subPKP' _ = error "This should never happen (subPKP')"
+
+verifyAgainstKey' ::
+     PKPayload -> Pkt -> Maybe UTCTime -> ByteString -> Either String Verification
+verifyAgainstKey' pkp sig mt payload = do
+--  FIXME: check flags
+--  FIXME: check expiration time
+      r <- verify'
+               sig
+               pkp
+               (hashalgo sig)
+               (BL.toStrict (finalPayload sig payload))
+--  FIXME: check signature hash against policy
+--  FIXME: check pka against policy
+      return (Verification r ((_signaturePayload . fromPkt) sig))
+  where
     verify' (SignaturePkt s) pub@(PKPayload V4 _ _ _ pkey) SHA1 pl =
       verify'' (pkaAndMPIs s) CHA.SHA1 pub pkey pl
     verify' (SignaturePkt s) pub@(PKPayload V4 _ _ _ pkey) RIPEMD160 pl =
@@ -317,20 +332,22 @@ verifyAgainstKeys ks sig mt payload = do
     hashalgo _ = error "This should never happen (hashalgo)."
     pkaAndMPIs (SigV4 _ pka _ _ _ _ mpis) = (pka, mpis)
     pkaAndMPIs _ = error "This should never happen (pkaAndMPIs)."
-    isSignatureExpired :: Pkt -> Maybe UTCTime -> Either String Bool
-    isSignatureExpired _ Nothing = return False
-    isSignatureExpired s (Just t) =
+    crazyHash h = BA.convert . hashWith h
+
+isSignatureExpired :: Pkt -> Maybe UTCTime -> Either String Bool
+isSignatureExpired _ Nothing = return False
+isSignatureExpired s (Just t) =
       if any
            (expiredBefore t)
            ((\(SigV4 _ _ _ h _ _ _) -> h) . _signaturePayload . fromPkt $ s)
         then Left "signature expired"
         else return True
+  where
     expiredBefore :: UTCTime -> SigSubPacket -> Bool
     expiredBefore ct (SigSubPacket _ (SigExpirationTime et)) =
       fromEnum ((posixSecondsToUTCTime . toEnum . fromEnum) et `diffUTCTime` ct) <
       0
     expiredBefore _ _ = False
-    crazyHash h = BA.convert . hashWith h
 
 finalPayload :: Pkt -> ByteString -> ByteString
 finalPayload s pl = BL.concat [pl, sigbit, trailer s]
