@@ -1,7 +1,8 @@
 -- Base.hs: OpenPGP (RFC4880) data types
--- Copyright © 2012-2018  Clint Adams
+-- Copyright © 2012-2022  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE DeriveGeneric #-}
@@ -21,6 +22,9 @@ import Control.Lens (makeLenses, op, Wrapped)
 import Control.Monad (mzero)
 import Data.Aeson ((.=), object)
 import qualified Data.Aeson as A
+#if MIN_VERSION_aeson(2,0,0)
+import qualified Data.Aeson.Key as AK
+#endif
 import qualified Data.Aeson.TH as ATH
 import Data.ByteArray (ByteArrayAccess)
 import qualified Data.ByteString as B
@@ -36,14 +40,11 @@ import Data.List.NonEmpty (NonEmpty)
 import qualified Data.List.NonEmpty as NE
 import Data.List.Split (chunksOf)
 import Data.Maybe (fromMaybe)
-import Data.Monoid ((<>))
 import Data.Ord (comparing)
-import Data.Semigroup (Semigroup)
 import Data.Set (Set)
 import qualified Data.Set as Set
 import Data.Text (Text)
 import qualified Data.Text as T
-import Data.Text.Prettyprint.Doc (Pretty(..), (<+>), hsep, punctuate, space)
 import Data.Time.Clock.POSIX (posixSecondsToUTCTime)
 import Data.Time.Format (formatTime)
 import Data.Time.Locale.Compat (defaultTimeLocale)
@@ -51,6 +52,7 @@ import Data.Typeable (Typeable)
 import Data.Word (Word16, Word32, Word8)
 import Network.URI (URI(..), nullURI, parseURI, uriToString)
 import Numeric (readHex)
+import Prettyprinter (Pretty(..), (<+>), hsep, punctuate, space)
 
 type Exportability = Bool
 
@@ -360,11 +362,17 @@ instance Hashable TwentyOctetFingerprint
 instance Pretty TwentyOctetFingerprint where
   pretty = pretty . take 40 . bsToHexUpper . unTOF
 
+#if MIN_VERSION_aeson(2,0,0)
+key = AK.fromText . T.pack
+#else
+key = T.pack
+#endif
+
 instance A.ToJSON TwentyOctetFingerprint where
-  toJSON e = object [T.pack "fpr" .= (A.toJSON . show . pretty) e]
+  toJSON e = object [key "fpr" .= (A.toJSON . show . pretty) e]
 
 instance A.FromJSON TwentyOctetFingerprint where
-  parseJSON (A.Object v) = TwentyOctetFingerprint . read <$> v A..: T.pack "fpr"
+  parseJSON (A.Object v) = TwentyOctetFingerprint . read <$> v A..: key "fpr"
   parseJSON _ = mzero
 
 newtype SpacedFingerprint =
@@ -408,10 +416,10 @@ instance Read EightOctetKeyId where
 instance Hashable EightOctetKeyId
 
 instance A.ToJSON EightOctetKeyId where
-  toJSON e = object [T.pack "eoki" .= (bsToHexUpper . op EightOctetKeyId) e]
+  toJSON e = object [key "eoki" .= (bsToHexUpper . op EightOctetKeyId) e]
 
 instance A.FromJSON EightOctetKeyId where
-  parseJSON (A.Object v) = EightOctetKeyId . read <$> v A..: T.pack "eoki"
+  parseJSON (A.Object v) = EightOctetKeyId . read <$> v A..: key "eoki"
   parseJSON _ = mzero
 
 newtype NotationName =
@@ -426,10 +434,10 @@ instance Pretty NotationName where
 instance Wrapped NotationName
 
 instance A.ToJSON NotationName where
-  toJSON nn = object [T.pack "notationname" .= show (op NotationName nn)]
+  toJSON nn = object [key "notationname" .= show (op NotationName nn)]
 
 instance A.FromJSON NotationName where
-  parseJSON (A.Object v) = NotationName . read <$> v A..: T.pack "notationname"
+  parseJSON (A.Object v) = NotationName . read <$> v A..: key "notationname"
   parseJSON _ = mzero
 
 newtype NotationValue =
@@ -444,11 +452,11 @@ instance Pretty NotationValue where
 instance Wrapped NotationValue
 
 instance A.ToJSON NotationValue where
-  toJSON nv = object [T.pack "notationvalue" .= show (op NotationValue nv)]
+  toJSON nv = object [key "notationvalue" .= show (op NotationValue nv)]
 
 instance A.FromJSON NotationValue where
   parseJSON (A.Object v) =
-    NotationValue . read <$> v A..: T.pack "notationvalue"
+    NotationValue . read <$> v A..: key "notationvalue"
   parseJSON _ = mzero
 
 data HashAlgorithm
@@ -673,8 +681,10 @@ instance FutureFlag FeatureFlag where
 
 instance Hashable FeatureFlag
 
+#if !MIN_VERSION_hashable(1,3,4)
 instance Hashable a => Hashable (Set a) where
   hashWithSalt salt = hashWithSalt salt . Set.toList
+#endif
 
 instance Pretty FeatureFlag where
   pretty ModificationDetection = pretty "modification-detection"
@@ -700,11 +710,11 @@ instance Pretty URL where
   pretty = pretty . (\uri -> uriToString id uri "") . op URL
 
 instance A.ToJSON URL where
-  toJSON u = object [T.pack "uri" .= (\uri -> uriToString id uri "") (op URL u)]
+  toJSON u = object [key "uri" .= (\uri -> uriToString id uri "") (op URL u)]
 
 instance A.FromJSON URL where
   parseJSON (A.Object v) =
-    URL . fromMaybe nullURI . parseURI <$> v A..: T.pack "uri"
+    URL . fromMaybe nullURI . parseURI <$> v A..: key "uri"
   parseJSON _ = mzero
 
 data SigType
@@ -930,63 +940,63 @@ instance Pretty SigSubPacketPayload where
     pretty "unknown signature subpacket type" <+> pretty t <+> prettyLBS bs
 
 instance A.ToJSON SigSubPacketPayload where
-  toJSON (SigCreationTime ts) = object [T.pack "sigCreationTime" .= ts]
-  toJSON (SigExpirationTime d) = object [T.pack "sigExpirationTime" .= d]
+  toJSON (SigCreationTime ts) = object [key "sigCreationTime" .= ts]
+  toJSON (SigExpirationTime d) = object [key "sigExpirationTime" .= d]
   toJSON (ExportableCertification e) =
-    object [T.pack "exportableCertification" .= e]
-  toJSON (TrustSignature tl ta) = object [T.pack "trustSignature" .= (tl, ta)]
+    object [key "exportableCertification" .= e]
+  toJSON (TrustSignature tl ta) = object [key "trustSignature" .= (tl, ta)]
   toJSON (RegularExpression apdre) =
-    object [T.pack "regularExpression" .= BL.unpack apdre]
-  toJSON (Revocable r) = object [T.pack "revocable" .= r]
-  toJSON (KeyExpirationTime d) = object [T.pack "keyExpirationTime" .= d]
+    object [key "regularExpression" .= BL.unpack apdre]
+  toJSON (Revocable r) = object [key "revocable" .= r]
+  toJSON (KeyExpirationTime d) = object [key "keyExpirationTime" .= d]
   toJSON (PreferredSymmetricAlgorithms sas) =
-    object [T.pack "preferredSymmetricAlgorithms" .= sas]
+    object [key "preferredSymmetricAlgorithms" .= sas]
   toJSON (RevocationKey rcs pka tof) =
-    object [T.pack "revocationKey" .= (rcs, pka, tof)]
-  toJSON (Issuer eoki) = object [T.pack "issuer" .= eoki]
+    object [key "revocationKey" .= (rcs, pka, tof)]
+  toJSON (Issuer eoki) = object [key "issuer" .= eoki]
   toJSON (NotationData nfs (NotationName nn) (NotationValue nv)) =
-    object [T.pack "notationData" .= (nfs, BL.unpack nn, BL.unpack nv)]
+    object [key "notationData" .= (nfs, BL.unpack nn, BL.unpack nv)]
   toJSON (PreferredHashAlgorithms phas) =
-    object [T.pack "preferredHashAlgorithms" .= phas]
+    object [key "preferredHashAlgorithms" .= phas]
   toJSON (PreferredCompressionAlgorithms pcas) =
-    object [T.pack "preferredCompressionAlgorithms" .= pcas]
+    object [key "preferredCompressionAlgorithms" .= pcas]
   toJSON (KeyServerPreferences kspfs) =
-    object [T.pack "keyServerPreferences" .= kspfs]
+    object [key "keyServerPreferences" .= kspfs]
   toJSON (PreferredKeyServer ks) =
-    object [T.pack "preferredKeyServer" .= show ks]
-  toJSON (PrimaryUserId p) = object [T.pack "primaryUserId" .= p]
-  toJSON (PolicyURL u) = object [T.pack "policyURL" .= u]
-  toJSON (KeyFlags kfs) = object [T.pack "keyFlags" .= kfs]
-  toJSON (SignersUserId u) = object [T.pack "signersUserId" .= u]
+    object [key "preferredKeyServer" .= show ks]
+  toJSON (PrimaryUserId p) = object [key "primaryUserId" .= p]
+  toJSON (PolicyURL u) = object [key "policyURL" .= u]
+  toJSON (KeyFlags kfs) = object [key "keyFlags" .= kfs]
+  toJSON (SignersUserId u) = object [key "signersUserId" .= u]
   toJSON (ReasonForRevocation rc rr) =
-    object [T.pack "reasonForRevocation" .= (rc, rr)]
-  toJSON (Features ffs) = object [T.pack "features" .= ffs]
+    object [key "reasonForRevocation" .= (rc, rr)]
+  toJSON (Features ffs) = object [key "features" .= ffs]
   toJSON (SignatureTarget pka ha sh) =
-    object [T.pack "signatureTarget" .= (pka, ha, BL.unpack sh)]
-  toJSON (EmbeddedSignature sp) = object [T.pack "embeddedSignature" .= sp]
+    object [key "signatureTarget" .= (pka, ha, BL.unpack sh)]
+  toJSON (EmbeddedSignature sp) = object [key "embeddedSignature" .= sp]
   toJSON (IssuerFingerprint kv ifp) =
-    object [T.pack "issuerFingerprint" .= (kv, ifp)]
+    object [key "issuerFingerprint" .= (kv, ifp)]
   toJSON (UserDefinedSigSub t bs) =
-    object [T.pack "userDefinedSigSub" .= (t, BL.unpack bs)]
-  toJSON (OtherSigSub t bs) = object [T.pack "otherSigSub" .= (t, BL.unpack bs)]
+    object [key "userDefinedSigSub" .= (t, BL.unpack bs)]
+  toJSON (OtherSigSub t bs) = object [key "otherSigSub" .= (t, BL.unpack bs)]
 
 uc3 :: (a -> b -> c -> d) -> (a, b, c) -> d
 uc3 f ~(a, b, c) = f a b c
 
 instance A.FromJSON SigSubPacketPayload where
   parseJSON (A.Object v) =
-    (SigCreationTime <$> v A..: T.pack "sigCreationTime") <|>
-    (SigExpirationTime <$> v A..: T.pack "sigExpirationTime") <|>
-    (ExportableCertification <$> v A..: T.pack "exportableCertification") <|>
-    (uncurry TrustSignature <$> v A..: T.pack "trustSignature") <|>
-    (RegularExpression . BL.pack <$> v A..: T.pack "regularExpression") <|>
-    (Revocable <$> v A..: T.pack "revocable") <|>
-    (KeyExpirationTime <$> v A..: T.pack "keyExpirationTime") <|>
+    (SigCreationTime <$> v A..: key "sigCreationTime") <|>
+    (SigExpirationTime <$> v A..: key "sigExpirationTime") <|>
+    (ExportableCertification <$> v A..: key "exportableCertification") <|>
+    (uncurry TrustSignature <$> v A..: key "trustSignature") <|>
+    (RegularExpression . BL.pack <$> v A..: key "regularExpression") <|>
+    (Revocable <$> v A..: key "revocable") <|>
+    (KeyExpirationTime <$> v A..: key "keyExpirationTime") <|>
     (PreferredSymmetricAlgorithms <$>
-     v A..: T.pack "preferredSymmetricAlgorithms") <|>
-    (uc3 RevocationKey <$> v A..: T.pack "revocationKey") <|>
-    (Issuer <$> v A..: T.pack "issuer") <|>
-    (uc3 NotationData <$> v A..: T.pack "notationData")
+     v A..: key "preferredSymmetricAlgorithms") <|>
+    (uc3 RevocationKey <$> v A..: key "revocationKey") <|>
+    (Issuer <$> v A..: key "issuer") <|>
+    (uc3 NotationData <$> v A..: key "notationData")
   parseJSON _ = mzero
 
 data SigSubPacket =
@@ -1005,7 +1015,8 @@ instance Pretty SigSubPacket where
 
 instance Hashable SigSubPacket
 
-$(ATH.deriveJSON ATH.defaultOptions ''SigSubPacket)
+instance A.ToJSON SigSubPacket
+instance A.FromJSON SigSubPacket
 
 $(makeLenses ''SigSubPacket)
 
