@@ -1,5 +1,5 @@
 -- CryptoniteNewtypes.hs: OpenPGP (RFC4880) newtype wrappers for some cryptonite types
--- Copyright © 2012-2018  Clint Adams
+-- Copyright © 2012-2022  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 {-# LANGUAGE DeriveDataTypeable #-}
@@ -17,8 +17,8 @@ import qualified Crypto.PubKey.RSA as RSA
 import qualified Data.Aeson as A
 import Data.Data (Data)
 import Data.Hashable (Hashable(..))
-import Data.Text.Prettyprint.Doc (Pretty(..), (<+>), tupled)
 import Data.Typeable (Typeable)
+import Prettyprinter (Pretty(..), (<+>), tupled)
 
 newtype DSA_PublicKey =
   DSA_PublicKey
