@@ -1,5 +1,5 @@
 -- PKITypes.hs: OpenPGP (RFC4880) data types for public/secret keys
--- Copyright © 2012-2019  Clint Adams
+-- Copyright © 2012-2022  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 {-# LANGUAGE DataKinds #-}
@@ -22,11 +22,10 @@ import Data.ByteString.Lazy (ByteString)
 import qualified Data.ByteString.Lazy as BL
 import Data.Data (Data)
 import Data.Hashable (Hashable(..))
-import Data.Monoid ((<>))
 import Data.Ord (comparing)
-import Data.Text.Prettyprint.Doc (Pretty(..), (<+>))
 import Data.Typeable (Typeable)
 import Data.Word (Word16)
+import Prettyprinter (Pretty(..), (<+>))
 
 data EdSigningCurve =
   Ed25519
